@@ -5,31 +5,56 @@ import os
 import sys
 import re
 from ctypes import CDLL, CFUNCTYPE, c_char_p, c_int
+from ctypes.util import find_library
 
 from django.contrib.gis.gdal.error import GDALException
 from django.core.exceptions import ImproperlyConfigured
 
 logger = logging.getLogger('django.contrib.gis')
 
-# This loads the GDAL/OGR C library.
-if os.name == 'posix':
-    platform = os.uname()[0]
-    if platform == 'Linux':
-        libname = 'libgdal.so'
-    elif platform == 'Darwin':
-        libname = 'libgdal.1.dylib'
-    lgdal = CDLL(os.path.join(sys.prefix, 'lib', libname))
+# Custom library path set?
+if 'linux' in sys.platform:
+    lib_path = os.path.join(sys.prefix, 'lib', 'libgdal.so')
+elif 'darwin' in sys.platform:
+    lib_path = os.path.join(sys.prefix, 'lib', 'libgdal.dylib')
 elif os.name == 'nt':
-    # On Windows, the GDAL binaries have some OSR routines exported with
-    # STDCALL, while others are not.  Thus, the library will also need to
-    # be loaded up as WinDLL for said OSR functions that require the
-    # different calling convention.
-    from ctypes import WinDLL
-    libname = os.path.join(sys.prefix, 'Library', 'bin', 'gdal111.dll')
-    lgdal = CDLL(libname)
-    lwingdal = WinDLL(libname)
+    lib_path = os.path.join(sys.prefix, 'Library', 'bin', 'gdal201.dll')
+
+if lib_path:
+    lib_names = None
+elif os.name == 'nt':
+    # Windows NT shared libraries
+    lib_names = ['gdal111', 'gdal110', 'gdal19', 'gdal18', 'gdal17']
+elif os.name == 'posix':
+    # *NIX library names.
+    lib_names = ['gdal', 'GDAL', 'gdal1.11.0', 'gdal1.10.0', 'gdal1.9.0',
+        'gdal1.8.0', 'gdal1.7.0']
 else:
-    raise Exception('No valid platform name. Found {}'.format(os.name))
+    raise GDALException('Unsupported OS "%s"' % os.name)
+
+# Using the ctypes `find_library` utility  to find the
+# path to the GDAL library from the list of library names.
+if lib_names:
+    for lib_name in lib_names:
+        lib_path = find_library(lib_name)
+        if lib_path is not None:
+            break
+
+if lib_path is None:
+    raise GDALException('Could not find the GDAL library (tried "%s"). '
+                       'Try setting GDAL_LIBRARY_PATH in your settings.' %
+                       '", "'.join(lib_names))
+
+# This loads the GDAL/OGR C library
+lgdal = CDLL(lib_path)
+
+# On Windows, the GDAL binaries have some OSR routines exported with
+# STDCALL, while others are not.  Thus, the library will also need to
+# be loaded up as WinDLL for said OSR functions that require the
+# different calling convention.
+if os.name == 'nt':
+    from ctypes import WinDLL
+    lwingdal = WinDLL(lib_path)
 
 
 def std_call(func):
